@@ -1,7 +1,7 @@
 """
 Type annotations for sso-admin service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/literals/)
 
 Usage::
 
@@ -36,7 +36,9 @@ __all__ = (
     "ProvisioningStatusType",
     "StatusValuesType",
     "TargetTypeType",
+    "SSOAdminServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -71,6 +73,7 @@ ProvisioningStatusType = Literal[
 ]
 StatusValuesType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED"]
 TargetTypeType = Literal["AWS_ACCOUNT"]
+SSOAdminServiceName = Literal["sso-admin"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -359,6 +362,18 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_account_assignment_creation_status",
     "list_account_assignment_deletion_status",
